<template>
  <div class="container-fluid p-4 mb-5 pb-5">
    <div class="row">
      <div class="col-sm-9 m-auto">
        <div class="row">
          <div v-if="data.step === 1" class="col-sm-12 my-3">
            <div class="row justify-content-center">
              <div class="col-sm-12">
                <h2>{{ t('account.advertise.create.index.step1_title') }}</h2>
              </div>
              <advertise-create-category-step v-model="data.form.category"/>
            </div>
          </div>
          <div v-if="data.step === 2" class="col-sm-12 my-3">
            <div class="row justify-content-center">
              <div class="col-sm-12">
                <h2>{{ t('account.advertise.create.index.step2_title') }}</h2>
              </div>
            </div>
            <advertise-create-detail-step v-model="data.form" @prevStep="prevStep" :errors="data.errors"/>
            <div class="row my-2">
              <div class="col-sm-12">
                <div class="alert bg-warning">
                  <i class="icon icon-regular-bell-on"></i>
                  <b>{{ t('account.advertise.create.index.alert_title') }}</b><br>
                  <hr>
                  <p>{{ t('account.advertise.create.index.alert_message') }}</p>
                  <ul>
                    <li v-for="index in 6" :key="index">{{ t('account.advertise.create.index.alert_list.' + index) }}</li>
                  </ul>
                </div>
              </div>
              <div class="col-sm-12 d-flex align-items-center justify-content-end">
                <button class="btn btn-default" @click="submitForm">{{
                    t('account.advertise.create.index.submit_button')
                  }}
                </button>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import {reactive, watch} from "vue";
import {useRouter} from "vue-router";

definePageMeta({
  layout: 'default',
  middleware: ['auth']
});

const {t} = useI18n()
const router = useRouter();
const {$api,$sweetalert,$validation} = useNuxtApp();
const data = reactive({
  step: 1,
  form: {
    images: [],
    attributes: [],
    category: {},
    exchange: false,
    phone: "",
    price: "12",
    title: "",
    content: "",
    requested: false,
    price_check: false,
    chat_request: false,
    hide_mobile: false,
    ai_request: false,
    discount_check: false,
    province_id: "",
    city_id: "",
    zone_id: "",
    discount: "",
    discount_start_date: "",
    discount_end_date: "",
    latitude: 35,
    longitude: 57
  },
  errors: {
    title: [],
    city_id: [],
    province_id: [],
  },
});

setInterval(() => {
  console.log(data.form.price)
},5000)

const validateData = () => {
  data.errors.title = {};
  data.errors.city_id = {};
  data.errors.province_id = {};

  data.errors.title = $validation.validate(data.form.title,['required','min:10'],'عنوان');
  data.errors.city_id = $validation.validate(data.form.city_id,['required'],'شهر');
  data.errors.province_id = $validation.validate(data.form.province_id,['required'],'استان');
}

const nextStep = () => {
  let check = false;
  if (data.step === 1) {
    if (Object.values(data.form.category).length > 0) {
      check = true;
    }
  }

  if (data.step === 2) {
    check = true;
  }

  if (check) {
    data.step++;
  }
}

const prevStep = () => {
  data.step--;
}

watch(() => data.form.category, (newValue) => {
  nextStep();
});

const checkErrors = () => {
  let output = true;
  Object.values(data.errors).forEach((error) => {
    if(error.length > 0) {
      output = false
    }
  });

  return output;
}

const submitForm = async () => {
  validateData();

 if(checkErrors) {
   let images = data.form.images.map((image) => {
     return image.id
   });

   await $api.post('/user/advertise/create', {
     images: images,
     attributes: data.form.attributes,
     category_id: data.form.category.id,
     title: data.form.title,
     price: !data.form.price_check ? data.form.price : '0',
     phone: data.form.phone,
     content: data.form.content,
     latitude: data.form.latitude,
     longitude: data.form.longitude,
     province_id: data.form.province_id,
     city_id: data.form.city_id,
     zone_id: data.form.zone_id,
     exchange: data.form.exchange,
     hide_mobile: data.form.hide_mobile,
     ai_request: data.form.ai_request,
     requested: data.form.requested,
     chat_request: data.form.chat_request,
     discount: data.form.discount,
     discount_start_date: data.form.discount_start_date,
     discount_end_date: data.form.discount_end_date,
       ...(data.form.business_id ? { business_id: data.form.business_id } : {})
   }).then((value) => {
     if (value.data.status) {
       $sweetalert.success(t('account.advertise.create.index.success_message'));

       if(value.data.data.price) {
         router.push('/account/advertise/upgrade/' + value.data.data.advertise_id)
       }else {
         router.push('/account/advertise')
       }
     }
   })
 }
}
</script>

<style scoped>

</style>